
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.006.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.28",
    "perl" => "5.010"
  },
  "dist_abstract" => "A plugin bundle for distributions built by OALDERS",
  "dist_author" => [
    "Olaf Alders <olaf\@wundercounter.com>"
  ],
  "dist_name" => "Dist-Zilla-PluginBundle-Author-OALDERS",
  "dist_version" => "0.000003",
  "license" => "perl",
  "module_name" => "Dist::Zilla::PluginBundle::Author::OALDERS",
  "recursive_test_files" => 1,
  "requires" => {
    "Dist::Zilla::Role::PluginBundle::Easy" => 0,
    "Dist::Zilla::Role::PluginBundle::PluginRemover" => 0,
    "List::AllUtils" => 0,
    "Moose" => 0,
    "Types::Path::Tiny" => 0,
    "Types::Standard" => 0,
    "feature" => 0,
    "perl" => "5.010",
    "strict" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "perl" => "5.010"
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "perl" => "5.010"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
